function  [nelements, neighWeights] = hists( data, binCenters )
% Computes a histogram of the input vector 'data' using soft-binning
%   data: (n x 1) column-vector
%   binCenters: histogram bin-centers, (1 x m) row-vector
%   
%   output
%     nelements: histogram entries, (1 x m) row-vector
%     neighWeights: (n x m) matrix. The ith row corresponds to the
%       ith data element and contains the weights contributing to the overall
%       histogram, such that nelements = sum(neighWeights,1).
%
%   (c) 2015 Robert Bensch, Image Analysis Group, Chair of Pattern Recognition and Image
%   Processing, University of Freiburg
%

    binx = abs(binCenters(2)-binCenters(1));

    d = abs(bsxfun(@minus, data, binCenters));  %d = abs(gsubtract( data, binCenters));
    neighBins = d<binx;
    neighWeights = 1-d./binx;
    neighWeights(~neighBins) = 0;
    neighWeights = bsxfun(@rdivide, neighWeights, sum(neighWeights,2)); %neighWeights = gdivide( neighWeights, sum(neighWeights,2));
    neighWeights(~neighBins) = 0;
    
    nelements = sum(neighWeights,1);    

end

