function runTracking( inDir, outDir, modelFile, lambda, sigma, useFillHoles, minSegmAreaPx, useFgrPropagation, useNonMergingConstr, FOI_E )
% Runs cell tracking method
%   inDir: input directory (expected input files format: t*.tif)
%   outDir: results output directory (output files format: mask*.tif)
%   modelFile: contains foreground/background model
%
%   (c) 2015 Robert Bensch, Image Analysis Group, Chair of Pattern Recognition and Image
%   Processing, University of Freiburg
%

%
% Cell segmentation
%

% Load foreground/background model
modelFile
ld = load(modelFile, 'model');     

% Parameter structure for segmentation
params = struct;
params.model = ld.model;

% Pre-processing
params.doPreSmoothing = 0;
params.preSmoothSigma = 0.5;

% Binary term
params.nNeigh = 8;
params.binaryTermType = 1;
params.wsigma = sigma;

% Lambda
params.lambda =  lambda;

% Post-processing
params.useFillHoles = useFillHoles;
params.minSegmAreaPx = minSegmAreaPx;

% Tracking / Segmentation propagation
params.useFgrPropagation = useFgrPropagation;
params.erosion_size = 15;
params.useNonMergingConstr = useNonMergingConstr;

params

% Run cell segmentation
fileStr_raw = [inDir 't*.tif']
predLabels = segmentCells( fileStr_raw, params);

% write predLabels
%{
hdf5write([inDir(1:end-1) '_predLabels.h5'],'/predLabels', predLabels);
%}

% read predLabels
%{
hdf5read([inDir(1:end-1) '_predLabels.h5'],'/predLabels');
%}


%
% Cell tracking
%

% Parameter structure for tracking
params = struct;
params.outDir = outDir;
params.useFillHoles = 0;
params.minSegmAreaPx = 0;
params.FOI_E = FOI_E;

params

% Run cell tracking
trackCells2(predLabels, params);

end

